@@ -77,9 +77,6 @@ def __validate_ids(args):
         Path(args.folder),
         None
     )
-    if not ids_is_valid:
-        print("Exiting...")
-        sys.exit(1)
 
 
 def __cmd(args):
