@@ -1,10 +1,14 @@
 import re
 
-meta_name_reg = re.compile('^[0-9a-zA-Z-_+ ]+$')
-meta_value_reg = re.compile('^[0-9a-zA-Z-_+., /]+$')
-tag_reg = re.compile('^[0-9a-zA-Z-_+. /]+$')
-label_name_reg = re.compile('^[0-9a-zA-Z-_+. ]+$')
-label_value_reg = re.compile('^[0-9a-zA-Z-_+., /]+$')
+# Please keep these regex is sync with:
+# https://github.com/tetrascience/ts-sdk-python/blob/main/ts_sdk/task/__util_validation.py
+
+meta_name_reg = re.compile(r'^[0-9a-zA-Z-_+ ]+$')
+meta_value_reg = re.compile(r'^[0-9a-zA-Z-_+.,/ ]+$')
+tag_reg = re.compile(r'^[0-9a-zA-Z-_+./ ]+$')
+label_name_reg = re.compile(r'^[0-9a-zA-Z-_+. ]+$')
+label_value_reg = re.compile(r'^[0-9a-zA-Z-_+.,/ ]+$')
+string_is_trimmed_reg = re.compile(r'^[^\s](.*[^\s])?$')
 
 
 def validate_file_meta(meta):
@@ -15,6 +19,8 @@ def validate_file_meta(meta):
             raise ValueError(f'Invalid metadata key {k}! Expected pattern: {meta_name_reg.pattern}')
         if not meta_value_reg.match(str(v)):
             raise ValueError(f'Invalid metadata value {v}! Expected pattern: {meta_value_reg.pattern}')
+        validate_string_is_trimmed(k)
+        validate_string_is_trimmed(v)
     return True
     
 
@@ -36,4 +42,14 @@ def validate_file_labels(labels):
             raise ValueError(f'Invalid label name {n}! Expected pattern: {label_name_reg.pattern}')
         if not label_value_reg.match(v):
             raise ValueError(f'Invalid label value {v}! Expected pattern: {meta_value_reg.pattern}')
-    return True
\ No newline at end of file
+        validate_string_is_trimmed(n)
+        validate_string_is_trimmed(v)
+    return True
+
+def validate_string_is_trimmed(s):
+    # Need to typecast non-string values to string in order to use the regex
+    if type(s) is not str:
+        s = str(s)
+    if not string_is_trimmed_reg.match(s):
+        raise ValueError(f'string \"{s}\" cannot contain leading or trailing spaces!')
+    return True
